==> llm-docs-0.1.5.tgz: package/docs/getting-started/quickstart.md <==
---
id: getting-started-quickstart
---
# Quick Start Guide

<!-- title: Quick Start Guide -->
<!-- description: Get up and running quickly with the LLM Platform Platform -->
<!-- lastUpdated: 2024-03-19 -->

This guide will help you get started quickly with the LLM Platform Platform. We'll walk through creating a new project, setting up the development environment, and running your first commands.

## Prerequisites

Before you begin, ensure you have completed the [installation guide](./installation) and have:
- Node.js 18+ installed
- llmcli installed globally
- Docker running
- Git configured
- Required API keys

## Create a New Project

1. Initialize a new project:
```bash
# Create a new project
llmcli init my-project

# Navigate to project directory
cd my-project
```

2. Configure the project:
```bash
# Set up environment variables
llmcli config set api.url https://api.bluefly.io
llmcli config set api.key your_api_key_here

# Verify configuration
llmcli config list
```

## Development Environment

1. Start the development environment:
```bash
# Start all services
llmcli dev start

# Check service status
llmcli dev status
```

2. Access the development dashboard:
- Open `http://localhost:3000` in your browser
- Log in with your credentials
- Navigate to the development section

## Your First Project

### 1. Create a New API Endpoint

```bash
# Generate API endpoint
llmcli api create endpoint my-endpoint

# Edit the endpoint
code src/api/endpoints/my-endpoint.ts
```

Example endpoint code:
```typescript
import { Endpoint, Request, Response } from '@bluefly/api';

export default class MyEndpoint extends Endpoint {
  async handle(request: Request): Promise<Response> {
    return {
      status: 200,
      body: {
        message: 'Hello from LLM Platform Platform!',
        timestamp: new Date().toISOString()
      }
    };
  }
}
```

### 2. Create an AI Agent

```bash
# Generate agent template
llmcli agent create my-agent

# Edit the agent
code src/agents/my-agent.ts
```

Example agent code:
```typescript
import { Agent, Task, Result } from '@bluefly/agent';

export default class MyAgent extends Agent {
  async execute(task: Task): Promise<Result> {
    const { input } = task;
    
    // Process the input
    const result = await this.processInput(input);
    
    return {
      success: true,
      output: result,
      metadata: {
        processedAt: new Date().toISOString()
      }
    };
  }

  private async processInput(input: string): Promise<string> {
    // Add your processing logic here
    return `Processed: ${input}`;
  }
}
```

### 3. Set Up Drupal Integration

```bash
# Initialize Drupal integration
llmcli drupal init

# Install required modules
llmcli drupal module install mcp mcp_client eca

# Configure Drupal connection
llmcli drupal config set url http://localhost:8080
llmcli drupal config set api_key your_drupal_api_key
```

## Testing Your Setup

1. Test the API endpoint:
```bash
# Start the API server
llmcli api serve

# Test the endpoint
curl http://localhost:3000/api/my-endpoint
```

2. Test the AI agent:
```bash
# Start the agent service
llmcli agent serve

# Send a test task
llmcli agent task create my-agent "Test input"
```

3. Test Drupal integration:
```bash
# Check Drupal connection
llmcli drupal status

# Test API communication
llmcli drupal api test
```

## Development Workflow

1. **Make Changes**
   - Edit your code
   - Run tests: `llmcli test`
   - Check linting: `llmcli lint`

2. **Version Control**
   ```bash
   # Create a new branch
   git checkout -b feature/my-feature

   # Commit changes
   git add .
   git commit -m "Add my feature"

   # Push to remote
   git push origin feature/my-feature
   ```

3. **CI/CD Pipeline**
   - Create a merge request
   - Wait for CI checks to pass
   - Get code review
   - Merge to main branch

## Monitoring

1. View logs:
```bash
# View all logs
llmcli logs

# View specific service logs
llmcli logs api
llmcli logs agent
llmcli logs drupal
```

2. Check metrics:
```bash
# View service metrics
llmcli metrics

# Monitor specific service
llmcli metrics api
```

## Next Steps

- [API Development Guide](../components/bfapi/development)
- [Agent Development Guide](../components/bfagent/development)
- [Drupal Integration Guide](../drupal/integration)
- [Deployment Guide](../operations/deployment)

## Troubleshooting

If you encounter issues:

1. Check service status:
```bash
llmcli status
```

2. View detailed logs:
```bash
llmcli logs --level debug
```

3. Restart services:
```bash
llmcli dev restart
```

4. Reset development environment:
```bash
llmcli dev reset
```

## Support

- [Documentation](../README)
- [GitLab Issues](https://gitlab.com/blueflyio/internal-projects/llm/-/issues)
- [CI/CD Pipeline](https://gitlab.com/blueflyio/internal-projects/llm/-/pipelines)
- [Wiki](https://gitlab.com/blueflyio/internal-projects/llm/-/wikis)

==> llm-docs-1.0.1.tgz: package/docs/getting-started/quickstart.md <==
---
id: getting-started-quickstart
---
# Quick Start Guide

<!-- title: Quick Start Guide -->
<!-- description: Get up and running quickly with the Bluefly Platform -->
<!-- lastUpdated: 2024-03-19 -->

This guide will help you get started quickly with the Bluefly Platform. We'll walk through creating a new project, setting up the development environment, and running your first commands.

## Prerequisites

Before you begin, ensure you have completed the [installation guide](./installation) and have:
- Node.js 18+ installed
- BFCLI installed globally
- Docker running
- Git configured
- Required API keys

## Create a New Project

1. Initialize a new project:
```bash
# Create a new project
bfcli init my-project

# Navigate to project directory
cd my-project
```

2. Configure the project:
```bash
# Set up environment variables
bfcli config set api.url https://api.bluefly.io
bfcli config set api.key your_api_key_here

# Verify configuration
bfcli config list
```

## Development Environment

1. Start the development environment:
```bash
# Start all services
bfcli dev start

# Check service status
bfcli dev status
```

2. Access the development dashboard:
- Open `http://localhost:3000` in your browser
- Log in with your credentials
- Navigate to the development section

## Your First Project

### 1. Create a New API Endpoint

```bash
# Generate API endpoint
bfcli api create endpoint my-endpoint

# Edit the endpoint
code src/api/endpoints/my-endpoint.ts
```

Example endpoint code:
```typescript
import { Endpoint, Request, Response } from '@bluefly/api';

export default class MyEndpoint extends Endpoint {
  async handle(request: Request): Promise<Response> {
    return {
      status: 200,
      body: {
        message: 'Hello from Bluefly Platform!',
        timestamp: new Date().toISOString()
      }
    };
  }
}
```

### 2. Create an AI Agent

```bash
# Generate agent template
bfcli agent create my-agent

# Edit the agent
code src/agents/my-agent.ts
```

Example agent code:
```typescript
import { Agent, Task, Result } from '@bluefly/agent';

export default class MyAgent extends Agent {
  async execute(task: Task): Promise<Result> {
    const { input } = task;
    
    // Process the input
    const result = await this.processInput(input);
    
    return {
      success: true,
      output: result,
      metadata: {
        processedAt: new Date().toISOString()
      }
    };
  }

  private async processInput(input: string): Promise<string> {
    // Add your processing logic here
    return `Processed: ${input}`;
  }
}
```

### 3. Set Up Drupal Integration

```bash
# Initialize Drupal integration
bfcli drupal init

# Install required modules
bfcli drupal module install mcp mcp_client eca

# Configure Drupal connection
bfcli drupal config set url http://localhost:8080
bfcli drupal config set api_key your_drupal_api_key
```

## Testing Your Setup

1. Test the API endpoint:
```bash
# Start the API server
bfcli api serve

# Test the endpoint
curl http://localhost:3000/api/my-endpoint
```

2. Test the AI agent:
```bash
# Start the agent service
bfcli agent serve

# Send a test task
bfcli agent task create my-agent "Test input"
```

3. Test Drupal integration:
```bash
# Check Drupal connection
bfcli drupal status

# Test API communication
bfcli drupal api test
```

## Development Workflow

1. **Make Changes**
   - Edit your code
   - Run tests: `bfcli test`
   - Check linting: `bfcli lint`

2. **Version Control**
   ```bash
   # Create a new branch
   git checkout -b feature/my-feature

   # Commit changes
   git add .
   git commit -m "Add my feature"

   # Push to remote
   git push origin feature/my-feature
   ```

3. **CI/CD Pipeline**
   - Create a merge request
   - Wait for CI checks to pass
   - Get code review
   - Merge to main branch

## Monitoring

1. View logs:
```bash
# View all logs
bfcli logs

# View specific service logs
bfcli logs api
bfcli logs agent
bfcli logs drupal
```

2. Check metrics:
```bash
# View service metrics
bfcli metrics

# Monitor specific service
bfcli metrics api
```

## Next Steps

- [API Development Guide](../components/bfapi/development)
- [Agent Development Guide](../components/bfagent/development)
- [Drupal Integration Guide](../drupal/integration)
- [Deployment Guide](../operations/deployment)

## Troubleshooting

If you encounter issues:

1. Check service status:
```bash
bfcli status
```

2. View detailed logs:
```bash
bfcli logs --level debug
```

3. Restart services:
```bash
bfcli dev restart
```

4. Reset development environment:
```bash
bfcli dev reset
```

## Support

- [Documentation](../README)
- [GitLab Issues](https://gitlab.com/blueflyio/internal-projects/llm/-/issues)
- [CI/CD Pipeline](https://gitlab.com/blueflyio/internal-projects/llm/-/pipelines)
- [Wiki](https://gitlab.com/blueflyio/internal-projects/llm/-/wikis)
